You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by da...@apache.org on 2007/11/07 09:14:30 UTC

svn commit: r592647 - in /webservices/axis2/trunk/c: src/core/transport/http/server/apache2/mod_axis2.c src/core/transport/http/server/simple_axis2_server/http_server_main.c util/include/axutil_log.h util/src/log.c

Author: damitha
Date: Wed Nov  7 00:14:29 2007
New Revision: 592647

URL: http://svn.apache.org/viewvc?rev=592647&view=rev
Log:
changed LOG_LEVEL_SERVICE to LOG_LEVEL_USER.
Added user level logging functionlity to apache2 module.

Modified:
    webservices/axis2/trunk/c/src/core/transport/http/server/apache2/mod_axis2.c
    webservices/axis2/trunk/c/src/core/transport/http/server/simple_axis2_server/http_server_main.c
    webservices/axis2/trunk/c/util/include/axutil_log.h
    webservices/axis2/trunk/c/util/src/log.c

Modified: webservices/axis2/trunk/c/src/core/transport/http/server/apache2/mod_axis2.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/src/core/transport/http/server/apache2/mod_axis2.c?rev=592647&r1=592646&r2=592647&view=diff
==============================================================================
--- webservices/axis2/trunk/c/src/core/transport/http/server/apache2/mod_axis2.c (original)
+++ webservices/axis2/trunk/c/src/core/transport/http/server/apache2/mod_axis2.c Wed Nov  7 00:14:29 2007
@@ -207,6 +207,10 @@
         {
             level = AXIS2_LOG_LEVEL_DEBUG;
         }
+        else if (!strcasecmp(str, "user"))
+        {
+            level = AXIS2_LOG_LEVEL_USER;
+        }
         else if (!strcasecmp(str, "trace"))
         {
             level = AXIS2_LOG_LEVEL_TRACE;

Modified: webservices/axis2/trunk/c/src/core/transport/http/server/simple_axis2_server/http_server_main.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/src/core/transport/http/server/simple_axis2_server/http_server_main.c?rev=592647&r1=592646&r2=592647&view=diff
==============================================================================
--- webservices/axis2/trunk/c/src/core/transport/http/server/simple_axis2_server/http_server_main.c (original)
+++ webservices/axis2/trunk/c/src/core/transport/http/server/simple_axis2_server/http_server_main.c Wed Nov  7 00:14:29 2007
@@ -220,7 +220,7 @@
     fprintf(stdout,
             "\t-l LOG_LEVEL\t log level, available log levels:"
             "\n\t\t\t 0 - critical    1 - errors 2 - warnings"
-            "\n\t\t\t 3 - information 4 - debug  5- service 6- trace"
+            "\n\t\t\t 3 - information 4 - debug  5- user 6- trace"
             "\n\t\t\t Default log level is 4(debug).\n");
     fprintf(stdout,
             "\t-f LOG_FILE\t log file, default is $AXIS2C_HOME/logs/axis2.log"

Modified: webservices/axis2/trunk/c/util/include/axutil_log.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_log.h?rev=592647&r1=592646&r2=592647&view=diff
==============================================================================
--- webservices/axis2/trunk/c/util/src/log.c (original)
+++ webservices/axis2/trunk/c/util/src/log.c Wed Nov  7 00:14:29 2007
@@ -234,7 +234,7 @@
             case AXIS2_LOG_LEVEL_TRACE:
                 level_str = "[...TRACE...] ";
                 break;
-            case AXIS2_LOG_LEVEL_SERVICE:
+            case AXIS2_LOG_LEVEL_USER:
                 break;
             }
             fprintf(stderr, "%s %s(%d) %s\n", level_str, file, line, buffer);
@@ -281,7 +281,7 @@
     case AXIS2_LOG_LEVEL_TRACE:
         level_str = "[...TRACE...] ";
         break;
-    case AXIS2_LOG_LEVEL_SERVICE:
+    case AXIS2_LOG_LEVEL_USER:
         break;
     }
     axutil_thread_mutex_lock(mutex);
@@ -339,7 +339,7 @@
 }
 
 AXIS2_EXTERN void AXIS2_CALL
-axutil_log_impl_log_service(
+axutil_log_impl_log_user(
     axutil_log_t * log,
     const axis2_char_t * filename,
     const int linenumber,
@@ -403,7 +403,7 @@
         }
 
         if (AXIS2_LOG_LEVEL_DEBUG <= log->level && 
-            log->level != AXIS2_LOG_LEVEL_SERVICE)
+            log->level != AXIS2_LOG_LEVEL_USER)
         {
             char value[AXIS2_LEN_VALUE + 1];
             va_list ap;
@@ -442,7 +442,7 @@
         }
 
         if (AXIS2_LOG_LEVEL_INFO <= log->level &&
-            log->level != AXIS2_LOG_LEVEL_SERVICE)
+            log->level != AXIS2_LOG_LEVEL_USER)
         {
             char value[AXIS2_LEN_VALUE + 1];
             va_list ap;
@@ -484,7 +484,7 @@
         }
 
         if (AXIS2_LOG_LEVEL_WARNING <= log->level &&
-            log->level != AXIS2_LOG_LEVEL_SERVICE)
+            log->level != AXIS2_LOG_LEVEL_USER)
         {
             char value[AXIS2_LEN_VALUE + 1];
             va_list ap;
@@ -663,7 +663,7 @@
         }
 
         if (AXIS2_LOG_LEVEL_TRACE <= log->level &&
-            log->level != AXIS2_LOG_LEVEL_SERVICE)
+            log->level != AXIS2_LOG_LEVEL_USER)
         {
             char value[AXIS2_LEN_VALUE + 1];
             va_list ap;



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/util/include/axutil_log.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_log.h Wed Nov  7 00:14:29 2007
@@ -72,8 +72,8 @@
         /** Debug level, logs everything */
         AXIS2_LOG_LEVEL_DEBUG,
         
-        /** Service level, logs only service level debug messages */
-        AXIS2_LOG_LEVEL_SERVICE,
+        /** User level, logs only user level debug messages */
+        AXIS2_LOG_LEVEL_USER,
 
         /** Trace level, Enable with compiler time option AXIS2_TRACE */
         AXIS2_LOG_LEVEL_TRACE
@@ -168,7 +168,7 @@
         ...);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axutil_log_impl_log_service(
+    axutil_log_impl_log_user(
         axutil_log_t * log,
         const axis2_char_t * filename,
         const int linenumber,
@@ -211,7 +211,7 @@
 #define AXIS2_LOG_WRITE(log, buffer, level, file) \
       axutil_log_write(log, buffer, level, file, AXIS2_LOG_SI)
 
-#define AXIS2_LOG_SERVICE axutil_log_impl_log_service
+#define AXIS2_LOG_USER axutil_log_impl_log_user
 #define AXIS2_LOG_DEBUG axutil_log_impl_log_debug
 #define AXIS2_LOG_INFO axutil_log_impl_log_info
 #define AXIS2_LOG_WARNING axutil_log_impl_log_warning

Modified: webservices/axis2/trunk/c/util/src/log.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/src/log.c?rev=592647&r1=592646&r2=592647&view=diff
==============================================================================